==> nmail-php-patch-2.3.1-to-2.4.0.tgz: nmail/index.php <==
<?
require_once('include/global.php');
require_once('include/file.php');
require_once('include/diary_lib.php');
require_once('conf.inc.php');


// set
	$CFG = array();
	#$CFG['TITLE'] = "<b>ʱȭ</b>";
	if ($G_SYS[DB] == 'oracle') 
	{
		$db_substr = 'SUBSTR';
	} else 
	{
		$db_substr = 'SUBSTRING';
	}	// if()


// data
	// [2006-07-25] ⺻ 
		$dfcon = get_default_config($AUTH['auth_m_no']);


	//  / ϼ
		get_mail_box();
		$mail_unread_cnt = 0;
		for ($i=0; $i<sizeof($G_SYS['USER_MAIL_BOX']); $i++)
		{
			if ($G_SYS['USER_MAIL_BOX'][$i]['mb_id'] == 'inbox')
			{
				$mail_unread_cnt = number_format($G_SYS['USER_MAIL_BOX'][$i]['mf_cnt']);
				break;			
			}	// if()
		}	// for()

		$mail_all_cnt = db_get_one("SELECT COUNT(*) FROM " . $AUTH['auth_m_mf_table'] . " WHERE m_no='". $AUTH['auth_m_no'] . "' AND mb_id='inbox'");
		$mail_all_cnt = number_format($mail_all_cnt);

	// 뷮
		$mbr = db_get_row("SELECT m_quota, m_forwarding_type, m_autoreply_isuse, m_bigfile_quota, m_webhard_quota FROM " . $TB['MEMBER'] . " WHERE m_no='". $AUTH['auth_m_no'] . "'");
		$m_quota_view = filesize_human($mbr['m_quota']*1024, 0);
		$DEBUG['db_mf_size']['start'] = getmicrotime();
		$q_hint = ($G_SYS[DB] == 'oracle') ? "/*+ ORDERED index_asc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MNO_MBID) */" : "";
		$mf_filesize_sum = db_get_one("SELECT ".$q_hint." SUM(mf_filesize) FROM " . $AUTH['auth_m_mf_table'] . " WHERE m_no='". $AUTH['auth_m_no'] . "'");
		$DEBUG['db_mf_size']['exec'] += getmicrotime() - $DEBUG['db_mf_size']['start'];
		$mf_filesize_view = filesize_human($mf_filesize_sum);
		$m_quota_rate = ceil($mf_filesize_sum / ($mbr['m_quota']*1024) * 100);

	// [2008-03-24] 뷮÷ 뷮
		$q = "SELECT ms_bigfile, ms_webhard FROM ".$TB['MEMBER_SIZE']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$mbr_size = db_get_row($q);

		$m_bigfile_quota = $mbr['m_bigfile_quota'];
		$m_bigfile_quota = $m_bigfile_quota*1024;
		$m_bigfile_quota_view = filesize_human($m_bigfile_quota, 0);

		$ms_bigfile = $mbr_size['ms_bigfile'];
		$ms_bigfile_view = filesize_human($ms_bigfile);

		$bigfile_free_size = $m_bigfile_quota - $ms_bigfile;
		if ($bigfile_free_size < 0)
			$bigfile_free_size = 0;

		$m_bigfile_quota_rate = @ceil($ms_bigfile / $m_bigfile_quota * 100);

	// [2008-03-24] ϵ 뷮
		$m_webhard_quota = $mbr['m_webhard_quota'];
		$m_webhard_quota = $m_webhard_quota*1024;
		$m_webhard_quota_view = filesize_human($m_webhard_quota, 0);

		$ms_webhard = $mbr_size['ms_webhard'];
		$ms_webhard_view = filesize_human($ms_webhard);

		$webhard_free_size = $m_webhard_quota - $ms_webhard;
		if ($webhard_free_size < 0)
			$webhard_free_size = 0;

		$m_webhard_quota_rate = @ceil($ms_webhard / $m_webhard_quota * 100);


	// [2008-03-25] ȯ漳
		$q = "SELECT COUNT(*) FROM ".$TB['SPAM_ALLOW']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_spam_allow_cnt = number_format(db_get_one($q));

		$q = "SELECT COUNT(*) FROM ".$TB['SPAM_REJECT']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_spam_reject_cnt = number_format(db_get_one($q));

		$q = "SELECT COUNT(*) FROM ".$TB['AUTO_FILTER']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_auto_filter_cnt = number_format(db_get_one($q));

		$q = "SELECT COUNT(*) FROM ".$TB['POP3']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_pop3_cnt = number_format(db_get_one($q));





	//  -  .  ó¥κ ϰ  .
		$week_diary_limit = $dfcon['m_cfg_week_diray_cnt'];		//  ̹  .
		$DEBUG['diary_week']['start'] = getmicrotime();
		// ޷°
			$_today = time();

			if ((!$stat_year)&&(!$stat_month))
			{
				$stat_year = date('Y', $_today);
				$stat_month = date('m', $_today);
			} else
			{
				$stat_month = sprintf('%02d', $stat_month);
			}	// if()

			$now_date = date('Y-m-d', $_today);		//  ¥
			$now_day = date('d', $_today);		//  

			$today = mktime(0, 0, 0, $stat_month, 1, $stat_year);
			$month_last_day = date('t', $today);		// ̹  
			$today_week = date('w', $today);
			#echo "<HR>today_week - " . $today_week;
			$_month_last_day_v = $month_last_day + $today_week;
			$month_last_day_v = $_month_last_day_v + (7 - ($_month_last_day_v % 7));

			#$startdate = $stat_year . "-" . $stat_month . "-01";
			$startdate = $now_date;
			#echo "<HR>startdate - " . $startdate;
			$enddate = date('Y-m-d', mktime(0, 0, 0, $stat_month, $now_day+6, $stat_year));
			#echo "<HR>enddate - " . $enddate;

			$startdate_lunar = substr(solartolunar($startdate), 5, 5);
			$enddate_lunar = substr(solartolunar($enddate), 5, 5);

			$startdate_md = substr($startdate, 5, 5);
			$enddate_md = substr($enddate, 5, 5);

			// ̹޿ ǥúκ.
			$thismonth_lunar = db_get_rows("SELECT solar_date, lunar_date FROM " . $TB['DIARY_LUNAR'] . " WHERE solar_date >= '" . $startdate . "' AND solar_date <= '" . $enddate . "' AND $db_substr(lunar_date,9,2) IN ('01','15')");

		// data
			// search
				$q_where = '';
			// db - select
				$DEBUG['db_select']['start'] = getmicrotime();

				// ų()Ǯ  12~1 ϶.
				if (substr($startdate_lunar, 0, 2) == '12' && substr($enddate_lunar, 0, 2) == '01')
				{
					$is_lunar_12_1 = true;
					$q_repeat_l = "
									($db_substr(di.di_startdate,6,5) <= '$startdate_lunar' AND $db_substr(di.di_enddate,6,5) >= '$startdate_lunar')
									OR ($db_substr(di.di_startdate,6,5) <= '12-31' AND $db_substr(di.di_enddate,6,5) >= '12-31')
									OR ($db_substr(di.di_startdate,6,5) >= '$startdate_lunar' AND $db_substr(di.di_enddate,6,5) <= '12-31')
									OR ($db_substr(di.di_startdate,6,5) <= '01-01' AND $db_substr(di.di_enddate,6,5) >= '01-01')
									OR ($db_substr(di.di_startdate,6,5) <= '$enddate_lunar' AND $db_substr(di.di_enddate,6,5) >= '$enddate_lunar')
									OR ($db_substr(di.di_startdate,6,5) >= '01-01' AND $db_substr(di.di_enddate,6,5) <= '$enddate_lunar')
						";
				} else
				{
					$is_lunar_12_1 = false;
					$q_repeat_l = "
									($db_substr(di.di_startdate,6,5) <= '$startdate_lunar' AND $db_substr(di.di_enddate,6,5) >= '$startdate_lunar')
									OR ($db_substr(di.di_startdate,6,5) <= '$enddate_lunar' AND $db_substr(di.di_enddate,6,5) >= '$enddate_lunar')
									OR (
										$db_substr(di.di_startdate,6,5) >= '$startdate_lunar' AND $db_substr(di.di_enddate,6,5) <= '$enddate_lunar'
										AND $db_substr(di.di_startdate,6,5) <= $db_substr(di.di_enddate,6,5)
									)
						";
				}	// if()

				$sql = "
					SELECT
						*
					FROM
						" . $TB['DIARY'] . " di
					WHERE
						(
							(
								(
									(di.di_startdate <= '$startdate' AND di.di_enddate >= '$startdate')
									OR (di.di_startdate <= '$enddate' AND di.di_enddate >= '$enddate')
									OR (di.di_startdate >= '$startdate' AND di.di_enddate <= '$enddate')
								)
								AND di.di_repeat != 'Y'
								AND di.di_repeat != 'L'
							)
							OR
							(
								(
									($db_substr(di.di_startdate,6,5) <= '$startdate_md' AND $db_substr(di.di_enddate,6,5) >= '$startdate_md')
									OR ($db_substr(di.di_startdate,6,5) <= '$enddate_md' AND $db_substr(di.di_enddate,6,5) >= '$enddate_md')
									OR ($db_substr(di.di_startdate,6,5) >= '$startdate_md' AND $db_substr(di.di_enddate,6,5) <= '$enddate_md')
								)
								AND di.di_repeat = 'Y'
							)
							OR
							(
								(
									" . $q_repeat_l . "
								)
								AND di.di_repeat = 'L'
							)
						)
						AND
						(
							di.m_no='" . $AUTH['auth_m_no'] . "'
						)
						" . $q_where . "
					ORDER BY
						di.di_startdate, di.di_starttime, di.di_enddate, di.di_endtime
					";
				#vd($sql);
				$rows = db_get_rows($sql, true, 0, $week_diary_limit);
				$rows_cnt = getarraycount($rows['di_subject']);
				$DEBUG['db_select']['exec'] += getmicrotime() - $DEBUG['db_select']['start'];

			// set - Ϻ ೻
				$view_day_no = array();
				$view_day = array();
				$view_day_kind = array();
				$view_day_top = array();
				$view_isholiday = array();
				$view_day_time = array();
				$day_cnt = 0;
				for ($i=0; $i<$rows_cnt; $i++)
				{
					#echo "<HR>__" . $rows['di_repeat'][$i] . '/' . $rows['di_startdate'][$i] . '/' . $rows['di_enddate'][$i];
					if ($rows['di_repeat'][$i] == 'L')		// ų() Ǯ϶     ȯ .
					{
						// [2006-12-08]
						$_sd_md = substr($rows['di_startdate'][$i], 5, 5);
						$rows['di_startdate'][$i] = lunartosolar(($stat_year - 1).'-'.$_sd_md);
						if (substr($rows['di_startdate'][$i], 0, 7) != $stat_year.'-'.$stat_month)
							$rows['di_startdate'][$i] = lunartosolar($stat_year.'-'.$_sd_md);

						$_ed_md = substr($rows['di_enddate'][$i], 5, 5);
						$rows['di_enddate'][$i] = lunartosolar(($stat_year - 1).'-'.$_ed_md);
						if (substr($rows['di_enddate'][$i], 0, 7) != $stat_year.'-'.$stat_month)
							$rows['di_enddate'][$i] = lunartosolar($stat_year.'-'.$_ed_md);
						/*
						if ($is_lunar_12_1 && substr($_sd_md, 0, 2) == '12')
						{
							$rows['di_startdate'][$i] = lunartosolar(($stat_year - 1).'-'.$_sd_md);
						} else
						{
							$rows['di_startdate'][$i] = lunartosolar($stat_year.'-'.$_sd_md);
						}	// if()

						if ($is_lunar_12_1 && substr($_ed_md, 0, 2) == '12')
						{
							$rows['di_enddate'][$i] = lunartosolar(($stat_year - 1).'-'.$_ed_md);
						} else
						{
							$rows['di_enddate'][$i] = lunartosolar($stat_year.'-'.$_ed_md);
						}	// if()
						*/
					} else if ($rows['di_repeat'][$i] == 'Y')		// ų() Ǯ϶ ̹ ȯ .
					{
						$rows['di_startdate'][$i] = $stat_year.'-'.substr($rows['di_startdate'][$i], 5, 5);
						$rows['di_enddate'][$i] = $stat_year.'-'.substr($rows['di_enddate'][$i], 5, 5);
					}	// if()
					#echo "<HR>___" . $rows['di_repeat'][$i] . '/' . $rows['di_startdate'][$i] . '/' . $rows['di_enddate'][$i];

					$_sd_sp = split("-", $rows['di_startdate'][$i]);
					$_sd_ts = mktime(0, 0, 0, $_sd_sp[1], $_sd_sp[2], $_sd_sp[0]);

					$_ed_sp = split("-", $rows['di_enddate'][$i]);
					$_ed_ts = mktime(0, 0, 0, $_ed_sp[1], $_ed_sp[2], $_ed_sp[0]);

					// Ⱓ
					$diaryday = (($_ed_ts - $_sd_ts) / (3600*24)) + 1;

					for ($j=1; $j<=$diaryday; $j++)
					{
						$_thisdate_ts = mktime(0, 0, 0, $_sd_sp[1], ($_sd_sp[2] + $j - 1), $_sd_sp[0]);
						$thisdate = date("Y-m-d", $_thisdate_ts);
						#$thisday = date("j", $_thisdate_ts);
						$thisday = date("Ymd", $_thisdate_ts);
						#$thisdayofweek = date("w", $_thisdate_ts);

						// Ⱓ 1 ̻ , õ   .
						if ( $diaryday == 1 ||  (($thisdate >= $startdate)&&($thisdate <= $enddate)) )
						{
							if ($rows['di_kind'][$i] == '0' && ($rows['di_content'][$i] == '' || $rows['di_content'][$i] == ''))		// /϶
							{
								#echo "<HR>/ : " . $thisday . '/' . $diaryday . '/' . $thisdate . '/' . $rows['di_subject'][$i];
								if ($rows['di_content'][$i] == '')
								{
									$view_isholiday[$thisday] = true;
								}	// if()
								if ($view_day_top[$thisday] != '')
									$view_day_top[$thisday] .= ' / ';
								$view_day_top[$thisday] .= $rows['di_subject'][$i];
							} else
							{
								$view_day_no[$thisday][] = $rows['di_no'][$i];
								$view_day[$thisday][] = $rows['di_subject'][$i];
								$view_day_kind[$thisday][] = $rows['di_kind'][$i];
								$view_day_time[$thisday][] = ($rows['di_isallday'][$i] == 'Y') ? 'Ϸ ' : substr($rows['di_starttime'][$i],0,5).'~'.substr($rows['di_endtime'][$i],0,5);
								// Ư  
								$day_cnt++;
								if ($day_cnt >= $week_diary_limit)
								{
									break 2;
								}		// if()
							}	// if()
						}	// if()
					}	// for()
				}	// for()
		$DEBUG['diary_week']['exec'] += getmicrotime() - $DEBUG['diary_week']['start'];


	// 
		$new_notice_limit = 5;		//   .
		$sql = "
			SELECT
				nt_no, nt_subject, nt_regdate
			FROM
				" . $TB['NOTICE'] . "
			WHERE
				d_no='" . $AUTH['auth_d_no'] . "' 
			ORDER BY
				nt_no DESC
			";
		$nt = db_get_rows($sql, 0, $new_notice_limit);
		$nt_view = array();
		for ($i=0; $i<sizeof($nt); $i++)
		{
			$nt_view[$i]['nt_subject'] = han_substr($nt[$i]['nt_subject'], 60);		
			$nt_view[$i]['nt_regdate'] = substr($nt[$i]['nt_regdate'], 5, 6);		
		}	// for()


	// ο  - ֱ  ¥   ϸ .
		$new_mail_limit = $dfcon['m_cfg_new_cnt'];		//   .
		$DEBUG['get_new_mail_list']['start'] = getmicrotime();
		#$new_mail_box = array('inbox', 'spam');
		$new_mail_box = explode('|', $dfcon['m_cfg_new_mail_box']);

		// [2007-01-31]   /   ϴ .  (⺻ false)
		if ($G_SYS['SPAM_CHECK_SKIP'])
		{
			$new_mail_box_tmp = array();
			for ($i=0; $i<sizeof($new_mail_box); $i++)
			{
				if ($new_mail_box[$i] != 'spam')
				{
					$new_mail_box_tmp[] = $new_mail_box[$i];
				}	// if()
			}	// for()
			$new_mail_box = $new_mail_box_tmp;
		}	// if()

		$q_hint = '';
		$q_stopkey = '';
		if ($G_SYS[DB] == 'oracle')
		{
			$q_stopkey = " AND ROWNUM <= '".$new_mail_limit."' ";
			// [2006-09-14] ¥   ȵǴ  .
			$q_hint = "/*+ ORDERED index_asc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MF_ARRIVAL_DATE) */";
		}	// if()		
		$nm = array();
		$nm_cnt = array();
		for ($mb=0; $mb<sizeof($new_mail_box); $mb++)
		{
			// get mb_name
				for ($i=0; $i<sizeof($G_SYS['USER_MAIL_BOX']); $i++)
				{
					if ($G_SYS['USER_MAIL_BOX'][$i]['mb_id'] == $new_mail_box[$mb])
					{
						$new_mail_box_name[] = $G_SYS['USER_MAIL_BOX'][$i]['mb_name'];
						break;			
					}	// if()
				}	// for()

			// mysql 3  ε  ϴ ɻ  ϱ .
				if ($G_SYS[DB] != 'oracle')
				{
					//$_mf_cnt_prev = 0;
					for ($i=1; $i<=4; $i++)
					{
						$_time = time();
						$_date = date('Y-m-d H:i:s', ($_time-(86400*round(pow(2.5,$i)))));
						$sql = "
							SELECT 
								COUNT(*) 
							FROM 
								".$AUTH['auth_m_mf_table']."
							WHERE
								m_no='". $AUTH['auth_m_no'] . "'
								AND mb_id='". $new_mail_box[$mb]. "'
								AND mf_arrival_date >= '".$_date."'
								AND mf_is_read='N'
							";
						$_mf_cnt = db_get_one($sql);
						// [2007-01-04]    ִµ  Ⱓ Ÿ    .
						/* if ($_mf_cnt_prev > 0 && $_mf_cnt_prev == $_mf_cnt)
						{
							break;
						} else */
						if ($_mf_cnt >= $new_mail_limit)
						{
							$q_stopkey = " AND mf_arrival_date >= '".$_date."' ";
							break;
						}	// if()
						//$_mf_cnt_prev = $_mf_cnt;
					}	// for()
				}	// if()

			$sql = "SELECT $q_hint mf_no, mf_from, mf_subject, mf_arrival_date FROM ".$AUTH['auth_m_mf_table']." $q_index WHERE m_no='". $AUTH['auth_m_no'] . "' AND mb_id='".$new_mail_box[$mb]."' " . $q_stopkey . " AND mf_is_read='N' ORDER BY mf_arrival_date DESC";
			$nm[$mb] = db_get_rows($sql, 0, $new_mail_limit);
			$nm_cnt[$mb] = sizeof($nm[$mb]);
			for ($i=0; $i<$nm_cnt[$mb]; $i++)
			{
				$nm[$mb][$i]['mf_subject'] = (trim($nm[$mb][$i]['mf_subject']) == NULL) ? '____' : htmlspecialchars_fix(han_substr($nm[$mb][$i]['mf_subject'],70));
				$_addr = mime_address_parse($nm[$mb][$i]['mf_from']);
				$nm[$mb][$i]['mf_from'] = htmlspecialchars_fix(han_substr($_addr['display'], 20));
				$nm[$mb][$i]['mf_arrival_date'] = get_short_date($nm[$mb][$i]['mf_arrival_date']);
			}	// for()
		}	// for()
		$DEBUG['get_new_mail_list']['exec'] += getmicrotime() - $DEBUG['get_new_mail_list']['start'];


	// [2006-07-26] ֱ Խù
		$new_board_limit = 5;		//   .
		$q = "
			SELECT 
				b.ba_no, b.b_no, b.b_subject, b.b_regdate
			FROM
				".$TB['BOARD_ADMIN']." ba,
				".$TB['BOARD']." b
			WHERE
				ba.d_no='".$G['DINFO']['d_no']."'
				AND ba.ba_no=b.ba_no
			ORDER BY
				b.b_no DESC
			";
		$new_board = db_get_rows($q, 0, $new_board_limit);
		$new_board_view = array();
		for ($i=0; $i<sizeof($new_board); $i++)
		{
			$new_board_view[$i]['b_subject'] = htmlspecialchars_fix($new_board[$i]['b_subject']);
			$new_board_view[$i]['b_regdate'] = substr($new_board[$i]['b_regdate'], 5, 6);			
		}	// for()


// skin view
	nskinset('main', 'index.html');
	include($NSKIN['view_layout']);


require_once('include/global_end.php');
?>

==> nmail-php-patch-2.5.2-to-2.6.1.tgz: nmail/index.php <==
<?
require_once('include/global.php');
require_once('include/file.php');
require_once('include/diary_lib.php');
require_once('include/latest_lib.php');
require_once('conf.inc.php');


// set
	$CFG = array();
	#$CFG['TITLE'] = "<b>ʱȭ</b>";
	if ($G_SYS[DB] == 'oracle') 
	{
		$db_substr = 'SUBSTR';
	} else 
	{
		$db_substr = 'SUBSTRING';
	}	// if()


// data
	// [2006-07-25] ⺻ 
		$dfcon = get_default_config($AUTH['auth_m_no']);


	//  / ϼ
		get_mail_box();
		$mail_unread_cnt = 0;
		for ($i=0; $i<sizeof($G_SYS['USER_MAIL_BOX']); $i++)
		{
			if ($G_SYS['USER_MAIL_BOX'][$i]['mb_id'] == 'inbox')
			{
				$mail_unread_cnt = number_format($G_SYS['USER_MAIL_BOX'][$i]['mf_cnt']);
				break;			
			}	// if()
		}	// for()

		$mail_all_cnt = db_get_one("SELECT COUNT(*) FROM " . $AUTH['auth_m_mf_table'] . " WHERE m_no='". $AUTH['auth_m_no'] . "' AND mb_id='inbox'");
		$mail_all_cnt = number_format($mail_all_cnt);

	// 뷮
		$mbr = db_get_row("SELECT m_quota, m_forwarding_type, m_autoreply_isuse, m_bigfile_quota, m_webhard_quota FROM " . $TB['MEMBER'] . " WHERE m_no='". $AUTH['auth_m_no'] . "'");
		$m_quota_view = filesize_human($mbr['m_quota']*1024, 1);
		$DEBUG['db_mf_size']['start'] = getmicrotime();
		$q_hint = ($G_SYS[DB] == 'oracle') ? "/*+ ORDERED index_asc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MNO_MBID) */" : "";
		$mf_filesize_sum = db_get_one("SELECT ".$q_hint." SUM(mf_filesize) FROM " . $AUTH['auth_m_mf_table'] . " WHERE m_no='". $AUTH['auth_m_no'] . "'");
		$DEBUG['db_mf_size']['exec'] += getmicrotime() - $DEBUG['db_mf_size']['start'];
		$mf_filesize_view = filesize_human($mf_filesize_sum);
		$m_quota_rate = ceil($mf_filesize_sum / ($mbr['m_quota']*1024) * 100);

	// [2008-03-24] 뷮÷ 뷮
		$q = "SELECT ms_bigfile, ms_webhard FROM ".$TB['MEMBER_SIZE']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$mbr_size = db_get_row($q);

		$m_bigfile_quota = $mbr['m_bigfile_quota'];
		$m_bigfile_quota = $m_bigfile_quota*1024;
		$m_bigfile_quota_view = filesize_human($m_bigfile_quota, 1);

		$ms_bigfile = $mbr_size['ms_bigfile'];
		$ms_bigfile_view = filesize_human($ms_bigfile);

		$bigfile_free_size = $m_bigfile_quota - $ms_bigfile;
		if ($bigfile_free_size < 0)
			$bigfile_free_size = 0;

		$m_bigfile_quota_rate = @ceil($ms_bigfile / $m_bigfile_quota * 100);

	// [2008-03-24] ϵ 뷮
		$m_webhard_quota = $mbr['m_webhard_quota'];
		$m_webhard_quota = $m_webhard_quota*1024;
		$m_webhard_quota_view = filesize_human($m_webhard_quota, 1);

		$ms_webhard = $mbr_size['ms_webhard'];
		$ms_webhard_view = filesize_human($ms_webhard);

		$webhard_free_size = $m_webhard_quota - $ms_webhard;
		if ($webhard_free_size < 0)
			$webhard_free_size = 0;

		$m_webhard_quota_rate = @ceil($ms_webhard / $m_webhard_quota * 100);


	// [2008-03-25] ȯ漳
		$q = "SELECT COUNT(*) FROM ".$TB['SPAM_ALLOW']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_spam_allow_cnt = number_format(db_get_one($q));

		$q = "SELECT COUNT(*) FROM ".$TB['SPAM_REJECT']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_spam_reject_cnt = number_format(db_get_one($q));

		$q = "SELECT COUNT(*) FROM ".$TB['AUTO_FILTER']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_auto_filter_cnt = number_format(db_get_one($q));

		$q = "SELECT COUNT(*) FROM ".$TB['POP3']." WHERE m_no='".$AUTH['auth_m_no']."'";
		$m_pop3_cnt = number_format(db_get_one($q));



	// 
		$new_notice_limit = 5;		//   .
		$sql = "
			SELECT
				nt_no, nt_subject, nt_regdate
			FROM
				" . $TB['NOTICE'] . "
			WHERE
				d_no='" . $AUTH['auth_d_no'] . "' 
			ORDER BY
				nt_no DESC
			";
		$nt = db_get_rows($sql, 0, $new_notice_limit);
		$nt_view = array();
		for ($i=0; $i<sizeof($nt); $i++)
		{
			$nt_view[$i]['nt_subject'] = han_substr_view($nt[$i]['nt_subject'], 60);		
			$nt_view[$i]['nt_regdate'] = substr($nt[$i]['nt_regdate'], 5, 6);		
		}	// for()


	// ο  - ֱ  ¥   ϸ .
		$new_mail_limit = $dfcon['m_cfg_new_cnt'];		//   .
		$DEBUG['get_new_mail_list']['start'] = getmicrotime();
		#$new_mail_box = array('inbox', 'spam');
		$new_mail_box = explode('|', $dfcon['m_cfg_new_mail_box']);

		// [2007-01-31]   /   ϴ .  (⺻ false)
		if ($G_SYS['SPAM_CHECK_SKIP'])
		{
			$new_mail_box_tmp = array();
			for ($i=0; $i<sizeof($new_mail_box); $i++)
			{
				if ($new_mail_box[$i] != 'spam')
				{
					$new_mail_box_tmp[] = $new_mail_box[$i];
				}	// if()
			}	// for()
			$new_mail_box = $new_mail_box_tmp;
		}	// if()

		$q_hint = '';
		$q_stopkey = '';
		if ($G_SYS[DB] == 'oracle')
		{
			$q_stopkey = " AND ROWNUM <= '".$new_mail_limit."' ";
			// [2006-09-14] ¥   ȵǴ  .
			$q_hint = "/*+ ORDERED index_asc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MF_ARRIVAL_DATE) */";
		}	// if()		
		$nm = array();
		$nm_cnt = array();
		for ($mb=0; $mb<sizeof($new_mail_box); $mb++)
		{
			// get mb_name
				for ($i=0; $i<sizeof($G_SYS['USER_MAIL_BOX']); $i++)
				{
					if ($G_SYS['USER_MAIL_BOX'][$i]['mb_id'] == $new_mail_box[$mb])
					{
						$new_mail_box_name[] = $G_SYS['USER_MAIL_BOX'][$i]['mb_name'];
						break;			
					}	// if()
				}	// for()

			// mysql 3  ε  ϴ ɻ  ϱ .
				if ($G_SYS[DB] != 'oracle')
				{
					//$_mf_cnt_prev = 0;
					for ($i=1; $i<=4; $i++)
					{
						$_time = time();
						$_date = date('Y-m-d H:i:s', ($_time-(86400*round(pow(2.5,$i)))));
						$sql = "
							SELECT 
								COUNT(*) 
							FROM 
								".$AUTH['auth_m_mf_table']."
							WHERE
								m_no='". $AUTH['auth_m_no'] . "'
								AND mb_id='". $new_mail_box[$mb]. "'
								AND mf_arrival_date >= '".$_date."'
								AND mf_is_read='N'
							";
						$_mf_cnt = db_get_one($sql);
						// [2007-01-04]    ִµ  Ⱓ Ÿ    .
						/* if ($_mf_cnt_prev > 0 && $_mf_cnt_prev == $_mf_cnt)
						{
							break;
						} else */
						if ($_mf_cnt >= $new_mail_limit)
						{
							$q_stopkey = " AND mf_arrival_date >= '".$_date."' ";
							break;
						} else 
						{
							// [2008-06-25]    ִµ  Ⱓ Ÿ    . - 2
							$q_stopkey = '';							
						}	// if()
						//$_mf_cnt_prev = $_mf_cnt;
					}	// for()
				}	// if()

			$sql = "SELECT $q_hint mf_no, mf_from, mf_subject, mf_arrival_date FROM ".$AUTH['auth_m_mf_table']." $q_index WHERE m_no='". $AUTH['auth_m_no'] . "' AND mb_id='".$new_mail_box[$mb]."' " . $q_stopkey . " AND mf_is_read='N' ORDER BY mf_arrival_date DESC";
			$nm[$mb] = db_get_rows($sql, 0, $new_mail_limit);
			$nm_cnt[$mb] = sizeof($nm[$mb]);
			for ($i=0; $i<$nm_cnt[$mb]; $i++)
			{
				$nm[$mb][$i]['mf_subject'] = (trim($nm[$mb][$i]['mf_subject']) == NULL) ? '____' : htmlspecialchars_fix(han_substr_view($nm[$mb][$i]['mf_subject'],70));
				$_addr = mime_address_parse($nm[$mb][$i]['mf_from']);
				$nm[$mb][$i]['mf_from'] = htmlspecialchars_fix(han_substr_view($_addr['display'], 20));
				$nm[$mb][$i]['mf_arrival_date'] = get_short_date($nm[$mb][$i]['mf_arrival_date']);
			}	// for()
		}	// for()
		$DEBUG['get_new_mail_list']['exec'] += getmicrotime() - $DEBUG['get_new_mail_list']['start'];


// [2008-08-19] 2.5   Ų ȣȯ 
	include('index_compat.inc.php');

// skin view
	nskinset('main', 'index.html');
	include($NSKIN['view_layout']);


require_once('include/global_end.php');
?>
